# arcospy

![Build Status](https://travis-ci.com/jeffcsauer/arcospy.svg?token=sRx5dHJBVzwnJnFuh3p9&branch=master)

----

Welcome to `arcospy`, the unofficial python version of the [R `arcos` package](https://github.com/wpinvestigative/arcos) maintained by the Washington Post. `arcospy` is the result of a class project carried out at the University of Maryland in the Fall of 2019. The project was motivated by the Washington Post’s data-driven [story](https://www.washingtonpost.com/graphics/2019/investigations/dea-pain-pill-database/#download-resources) on a large pain pill database recently made publicly available. 

The `arcospy` module was built to offer the exact same functionality as `arcos`, with the only difference being the ability to run the API calls in python! All of the commands in `arcospy` inherit the names from the original commands in `arcos`. Both `arcos` and `arcospy` act as wrappers for the [DEA ARCOS dataset](https://arcos-api.ext.nile.works/__swagger__/). 

**Disclaimer: please note that the author of this package, Jeff Sauer, is not affiliated with the Washington Post in any official capacity.** 

----
